@@ -1400,6 +1400,7 @@ protected:
 	unsigned avail;
 	unsigned span, spans;	
 	bool running;
+	static bool stopping;
 	std::ostream *logevents;
 
 	int audio_priority;
@@ -1458,6 +1459,12 @@ public:
 	static inline bool useProtocols(void)
 		{return protocols;}
 
+	/**
+	 * Return is stopping flag.
+	 */
+	static bool isStopping(void)
+		{return stopping;};
+
 	/**
 	 * Return primary trunk driver, if driver trunking...
 	 */
