@@ -38,6 +38,15 @@ const char *BayonneBinder::submit(const char **args)
 	return NULL;
 }
 
+ScriptCompiler *BayonneBinder::compiler(void)
+{
+	ScriptCompiler *img = new ScriptCompiler(server, "/bayonne/server/config");
+	if(getUserdata())
+		img->loadPrefix("config", "~bayonne/config");
+
+	return img;
+}
+
 bool BayonneBinder::scriptEvent(ScriptInterp *interp, const char *evt)
 {
 	return (session(interp))->stringEvent(evt);
@@ -48,6 +57,11 @@ bool BayonneBinder::digitEvent(ScriptInterp *interp, const char *evt)
 	return (session(interp))->digitEvent(evt);
 }
 
+ScriptCompiler *BayonneBinder::getCompiler(void)
+{
+	return binder->compiler();
+}
+
 const char *BayonneBinder::submitRequest(const char **args)
 {
 	return binder->submit(args);
