@@ -19,6 +19,7 @@
 using namespace ost;
 using namespace std;
 
+bool BayonneDriver::stopping = false;
 bool BayonneDriver::protocols = true;
 BayonneDriver *BayonneDriver::firstDriver = NULL;
 BayonneDriver *BayonneDriver::lastDriver = NULL;
@@ -375,8 +376,9 @@ void BayonneDriver::stopDriver(void)
 		{
 			memset(&event, 0, sizeof(event));
 			event.id = SYSTEM_DOWN;
-//			session->putEvent(&event);
-			delete session;
+			session->enter();
+			session->postEvent(&event);
+			session->leave();
 		}
 	}
 
@@ -439,7 +441,31 @@ void BayonneDriver::reload(void)
 
 void BayonneDriver::stop(void) 
 {
+	BayonneSession *s;
         BayonneDriver *driver = firstDriver;
+	unsigned ts = 0;
+	Event event;
+
+	slog.notice("driver(s) stopping...");
+
+	stopping = true;
+
+	while(ts < ts_used)
+	{
+		s = getSession(ts++);
+		if(!s)
+			continue;
+		s->enter();
+		if(!s->isIdle())
+		{
+			memset(&event, 0, sizeof(event));
+			event.id = STOP_SCRIPT;
+			s->postEvent(&event);
+		}
+		s->leave();
+	}
+
+	Thread::sleep(1000);
 	
         while(driver)
         {
@@ -455,6 +481,9 @@ BayonneSession *BayonneDriver::getIdle(void)
 {
 	BayonneSession *session = NULL;
 
+	if(stopping)
+		return NULL;
+
 	enter();
 	if(firstIdle)
 	{
