@@ -808,6 +808,9 @@ void Driver::stopDriver(void)
 	ScriptImage *img;
 	Registry *reg;
 	SIPThread *thread;
+	unsigned c = count;
+	timeslot_t ts = timeslot;
+	BayonneSession *s;
 
 	if(running)
 	{
@@ -818,14 +821,13 @@ void Driver::stopDriver(void)
 			reg = (Registry *)img->getPointer("_sip_registry_");
 			while(reg)
 			{
-				if(strnicmp(reg->type, "ext", 3))
+				if(strnicmp(reg->type, "ext", 3) || stricmp(reg->type, "peer"))
 					updateExpires(reg, 0);
 				reg = reg->next;
 			}
 			endImage(img);
 		}
-		__eXosip_wakeup_event();
-		terminate();
+		Thread::sleep(500);
 		thread = SIPThread::first;
 		while(thread)
 		{
@@ -833,7 +835,18 @@ void Driver::stopDriver(void)
 			thread = thread->next;
 		}
 		SIPThread::first = NULL;
+		Driver::sip.terminate();
 		eXosip_quit();
+
+		while(c--)
+		{
+			s = getSession(ts++);
+			if(!s)
+				continue;
+//			s->makeIdle();
+		}
+		
+		Thread::sleep(120);
 		BayonneDriver::stopDriver();
 	}
 }
@@ -965,14 +978,8 @@ bool Driver::getRegistry(eXosip_event_t *sevent, Registry **reg, ScriptImage *im
 
 	*reg = NULL;	
 
-	eXosip_lock();
         if(osip_message_get_proxy_authorization(sevent->request, 0, &auth) != 0)
-	{
-		eXosip_unlock();
 		return true;
-	}
-
-	eXosip_unlock();
 
 	if(!auth)
 		return true;
@@ -1100,14 +1107,12 @@ void Driver::registerRequest(eXosip_event_t *sevent)
 	char *cp;
 	InetAddress addr;
 
-	eXosip_lock();
 	if(osip_message_get_authorization(sevent->request, 0, &auth) != 0)
 		goto challenge;
 
 	if(!auth || !auth->username || !auth->response)
 		goto challenge;
 
-	eXosip_unlock();
 	remove_quotes(auth->username);
 	remove_quotes(auth->uri);
 	remove_quotes(auth->nonce);
@@ -1176,7 +1181,6 @@ sip200:
 		publishUpdate(sevent, reg);
 		goto answer200;
 	}
-	eXosip_lock();	
 	osip_message_get_expires(sevent->request, 0, &exp);
 	if(exp && exp->hvalue)
 		pos = osip_atoi(exp->hvalue);
@@ -1185,7 +1189,7 @@ sip200:
 
 	if(pos < 0)
 		pos = 600;
-	eXosip_unlock();
+
 	if(pos)
 	{
 		time(&reg->traffic->updated);
@@ -1214,6 +1218,7 @@ answer200:
 	return;
 
 challenge:
+	eXosip_lock();
 	eXosip_message_build_answer(sevent->tid, 401, &reply);
 	snprintf(buf, sizeof(buf), 
 		"Digest realm=\"%s\", nonce=\"%s\"", realm, nonce);
@@ -1523,20 +1528,20 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(reg->regid < 0)
 		return "cannot create sip registration";
 
-	if(reg->secret)
-		setAuthentication(reg, NULL);
+//	if(reg->secret)
+//		setAuthentication(reg, NULL);
 
 //	osip_message_set_supported(msg, "path");   
 	osip_message_set_header(msg, "Event", "Registration");
 	osip_message_set_header(msg, "Allow-Events", "presence");
 
-/*	cp = getLast("transport");
+	cp = getLast("transport");
 	if(cp && !stricmp(cp, "tcp"))
 		eXosip_transport_set(msg, "TCP"); 
 	else if(cp && !stricmp(cp, "tls"))
 		eXosip_transport_set(msg, "TLS");
 
-
+/*
 	reg->route = ScriptChecks::findKeyword(line, "route");
 	if(reg->route && reg->route[0])
 	{
@@ -1650,10 +1655,10 @@ void Driver::run(void)
 	for(;;)
         {
 		sevent = eXosip_event_wait(0, event_timer);
-		eXosip_lock();
+/*		eXosip_lock();
 		eXosip_automatic_action();
 		eXosip_unlock();
-
+*/
 		Thread::yield();
 
 		if(exiting)
@@ -1714,6 +1719,9 @@ void Driver::run(void)
 			{
 				setAuthentication(reg, sevent->response);
 				server->leave();
+				eXosip_lock();
+				eXosip_automatic_action();
+				eXosip_unlock();
 				break;
 			}
 			if(reg)
@@ -2283,7 +2291,6 @@ killit:
 				goto cleanup;
 			}
 
-			eXosip_lock();
 			osip_message_header_get_byname(sevent->request, "session-expires", 0, &header);
 			if(header && header->hvalue)
 			{
@@ -2297,7 +2304,6 @@ killit:
 				expires = 0;
 				session->session_timer = 0;
 			}
-			eXosip_unlock();
 
 			if(expires)
 				slog.debug("%s: reconnecting %s:%d; expires=%ld seconds",
