@@ -264,6 +264,7 @@ bool Session::enterSeize(Event *event)
 {
 	char buf[128];
 	char cref[64];
+	char nbuf[16];
 	const char *cp, *to, *from = NULL;
 	char *sp = NULL;
 	osip_message_t *invite = NULL;
@@ -434,6 +435,8 @@ dialing:
 			else
 				snprintf(rbuf, sizeof(rbuf), 
 					"sipreg.%d", reg->regid);
+			snprintf(nbuf, sizeof(nbuf), "%ld", reg->traffic->sequence);
+			setConst("session.sequence", nbuf);
 			setConst("session.registry", rbuf);
 			setConst("session.uri_server", reg->proxy);
 			setConst("session.uri_local", reg->contact);
