@@ -752,7 +752,7 @@ bool Runtime::loadBinder(const char *path)
 #endif 
 
 #ifdef  WIN32
-        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.%s", prefix, path, RLL_SUFFIX);
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s%s", prefix, path, RLL_SUFFIX);
 #else
         snprintf(pathbuf, sizeof(pathbuf), "%s/%s.bin", prefix, path);
 #endif  
